@@ -1,7 +1,10 @@
 /**
- * $Id: vector.h,v 1.1 2004/06/21 11:28:00 jklein Exp $
+ * $Id: vector.h,v 1.2 2004/06/21 16:44:17 jklein Exp $
  * $Author: jklein $
  * $Log: vector.h,v $
+ * Revision 1.2  2004/06/21 16:44:17  jklein
+ * Added iterator.
+ *
  * Revision 1.1  2004/06/21 11:28:00  jklein
  * Changed source tree.
  *
@@ -14,6 +17,7 @@
 #define _SC_VECTOR_H_
 
 #include "scale/commons.h"
+#include "scale/iterator.h"
 
 typedef struct _vector svector_t;
 
@@ -26,7 +30,7 @@ struct _vector {
 };
 
 
-svector_t *		s_vector_alloc();
+svector_t *		s_vector_alloc(void);
 svector_t *		s_vector_allocn(size_t);
 void			s_vector_free(svector_t *);
 size_t			s_vector_size(svector_t *);
@@ -36,6 +40,7 @@ spointer		s_vector_remove(svector_t *, size_t);
 sint32			s_vector_find(svector_t *, sc_compf_t, spointer);
 sboolean		s_vector_join(svector_t *, svector_t *);
 
+siterator_t *	s_vector_iterator(svector_t *);
 
 
 #endif /* _SC_VECTOR_H_ */
